<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/">
    <head>
        <title>$title</title>

        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />

        <style type="text/css">
            table { width: 100% }
            th { text-align: left }
        </style>
    </head>

    <body>
        <h1>$title</h1>

        <hr />
        <table>
            <tr>
                <th>Filename</th>
                <th>size</th>
                <th>DDS</th>
                <th>DAS</th>
            </tr>
            <tr>
                <td><a href="../">Parent directory</a></td>
                <td colspan="3"></td>
            </tr>

            <!-- diretories -->
            <tr py:for="dir in dirs">
                <td><a href="${dir}/">${dir}/</a></td><td colspan="3"></td>
            </tr>

            <!-- files -->
            <tr py:for="file in files">
                <td py:choose="">
                    <a py:when="file.supported" href="${file.name}.html">${file.name}</a>
                    <py:otherwise>${file.name}</py:otherwise>
                </td>

                <td><a href="${file.name}" title="Download file">${file.size}</a></td> 

                <td py:choose="">
                    <a py:when="file.supported" href="${file.name}.dds">DDS</a>
                    <py:otherwise></py:otherwise>
                </td>

                <td py:choose="">
                    <a py:when="file.supported" href="${file.name}.das">DAS</a>
                    <py:otherwise></py:otherwise>
                </td>
            </tr>
        </table>

        <hr />
        <p><em><a href="http://pydap.org/">pydap/$version</a></em> &copy; Roberto De Almeida</p>
    </body>
</html>

<!--! vim:ft=genshi
-->
