<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
        <title>pyDAP help page for file $location</title>

        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    </head>

    <body>
        <h1>How to access this file</h1>

        <p>The resource <code>$location</code> is a dataset available through the <a href="http://opendap.org/">OPeNDAP</a> protocol. The best way to access this dataset is using an <a href="http://www.opendap.org/faq/whatClients.html">OPeNDAP client</a> like Ferret, GrADS or Matlab.</p>

        <p>In case you <strong>don't have</strong> a client installed, you can try to download data by accessing the <a href="${location}.html">web interface</a> for this dataset.</p>

        <hr />
        <p><em><a href="http://pydap.org/">pydap/$version</a></em> &copy; Roberto De Almeida</p>
    </body>
</html>

<!--! vim:ft=genshi
-->
